<?php
/**
 * Dorian Theme Customizer
 *
 * @package Dorian
 */

/**
 * Add some options to the Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function dorian_customize_register( $wp_customize ) {
	
	//Ability to pick a color scheme 
	//Setting
	$wp_customize->add_setting( 'dorian_color_scheme' , array(
		'default'     => '',
		'type' => 'theme_mod',
		'sanitize_callback'    => 'dorian_sanitize_color_scheme'
	) );
	
	//Control
	$wp_customize->add_control(
		'dorian_color_scheme_control',
		array(
			'type' => 'radio',
			'label' => __( 'Select a color scheme', 'dorian' ),
			'section' => 'colors',
			'choices' => array(
				'default' => __( 'Dark Purple', 'dorian' ),
				'red' => __( 'Red', 'dorian' ),
				'blue' => __( 'Blue', 'dorian' )
			),
			'settings' => 'dorian_color_scheme'
		)
	);
	
	//Add new section to add modifications to the presentation of some textual parts 
	$wp_customize->add_section('dorian_text_presentation', array(
		'title' => __('Site Presentation', 'dorian'),
		'priority' => 80,
		'description' => __('Modifications to the presentation of some textual parts of your theme.', 'dorian'),
	));
	
	//Add options for the text presentation section: change footer text,
	//select excerpt or full content for sticky post on index page,
	
	//Change text in the footer section 
	$wp_customize->add_setting( 'dorian_footer_text' , array(
		'default'     => '',
		'type' => 'theme_mod',
		'sanitize_callback'    => 'dorian_sanitize_textbox'
	) );

	//The control for text footer setting 
	$wp_customize->add_control('dorian_footer_text_control', array(
		'label' => __( 'Add the text for your footer', 'dorian' ),
		'section' => 'dorian_text_presentation',
		'settings' => 'dorian_footer_text',
		'type' => 'text',
	));
	
	//Choose to display excerpt of full content for sticky post on index page 
	//Setting
	$wp_customize->add_setting( 'dorian_sticky_post_display' , array(
		'default'     => 'excerpt',
		'type' => 'theme_mod',
		'sanitize_callback'    => 'dorian_sanitize_sticky_display'
	) );
	
	//Control
	$wp_customize->add_control(
		'dorian_sticky_post_display_control',
		array(
			'type' => 'radio',
			'label' => __( 'Display of sticky post or first post on blog index page', 'dorian' ),
			'section' => 'dorian_text_presentation',
			'choices' => array(
				'excerpt' => __( 'Excerpt', 'dorian' ),
				'full' => __( 'Full content', 'dorian' )
			),
			'settings' => 'dorian_sticky_post_display'
		)
	);
	
}
add_action( 'customize_register', 'dorian_customize_register' );

//Sanitizing input functions 
function dorian_sanitize_textbox( $input ) {
    return wp_kses_post( force_balance_tags( $input ) );
}

function dorian_sanitize_sticky_display( $input ) {
	if ( ! in_array( $input, array( 'excerpt', 'full' ) ) )
        $input = 'excerpt';
 
    return $input;
}

function dorian_sanitize_color_scheme( $input ) {
	if ( ! in_array( $input, array( 'default' ,'red', 'blue' ) ) )
        $input = 'default';
 
    return $input;
}

//Function to display CSS 
function dorian_customizer_css() {

	$selected_color_scheme = get_theme_mod( 'dorian_color_scheme' );
	//default
	$color_scheme = 'default';
	
	if ( $selected_color_scheme == 'blue' ) {
		$color_scheme = 'blue';
	}
	elseif ( $selected_color_scheme == 'red' ) {
		$color_scheme = 'red';
	}
	else {
		$color_scheme = '';
	}

?>
	<link rel="stylesheet" href="<?php echo get_template_directory_uri();?>/css/<?php echo $color_scheme; ?>.css" media="screen">
    <?php
	
}
add_action( 'wp_head', 'dorian_customizer_css' );